---------------------------
-- Default awesome theme --
---------------------------

local theme_assets = require("beautiful.theme_assets")
local xresources = require("beautiful.xresources")
local awful = require("awful")

local dpi = xresources.apply_dpi
local files = awful.util.getdir("config") .. "/theme"
local theme = {}

theme.font          = "Liberation Mono 9"

theme.bg_normal     = "#252a35"
theme.bg_focus      = "#5294e2"
theme.bg_urgent     = "#ca674a"
theme.bg_minimize   = "#a9a9a9"
theme.bg_systray    = theme.bg_normal

theme.fg_normal     = "#eeeeee"
theme.fg_focus      = theme.fg_normal
theme.fg_urgent     = theme.fg_normal
theme.fg_minimize   = theme.fg_normal

theme.border_width  = dpi(2)
theme.border_normal = "#4b5165"
theme.border_focus  = "#5294e2"
theme.border_marked = "#91231c"

theme.taglist_spacing     = dpi(4)
theme.taglist_bg_occupied = "#4b5165"

theme.tasklist_bg_normal = "#4b5165"
theme.tasklist_spacing   = dpi(4)

theme.useless_gap             = dpi(4)
theme.maximized_honor_padding = true

-- There are other variable sets
-- overriding the default one when
-- defined, the sets are:
-- taglist_[bg|fg]_[focus|urgent|occupied|empty|volatile]
-- tasklist_[bg|fg]_[focus|urgent]
-- titlebar_[bg|fg]_[normal|focus]
-- tooltip_[font|opacity|fg_color|bg_color|border_width|border_color]
-- mouse_finder_[color|timeout|animate_timeout|radius|factor]
-- prompt_[fg|bg|fg_cursor|bg_cursor|font]
-- hotkeys_[bg|fg|border_width|border_color|shape|opacity|modifiers_fg|label_bg|label_fg|group_margin|font|description_font]
-- Example:
--theme.taglist_bg_focus = "#ff0000"

-- Generate taglist squares:
local taglist_square_size = dpi(4)
theme.taglist_squares_sel = theme_assets.taglist_squares_sel(
    taglist_square_size, theme.fg_normal
)
theme.taglist_squares_unsel = theme_assets.taglist_squares_unsel(
    taglist_square_size, theme.fg_normal
)

-- Variables set for theming notifications:
-- notification_font
-- notification_[bg|fg]
-- notification_[width|height|margin]
-- notification_[border_color|border_width|shape|opacity]
theme.notification_border_color = "#4b5165"
theme.notification_border_width = dpi(2)
theme.notification_icon_size    = dpi(64)
theme.notification_margin       = dpi(4)
theme.notification_max_height   = dpi(72)
theme.notification_max_width    = dpi(640)

-- Variables set for theming the menu:
-- menu_[bg|fg]_[normal|focus]
-- menu_[border_color|border_width]
theme.menu_submenu_icon = files.."/submenu.png"
theme.menu_height = dpi(15)
theme.menu_width  = dpi(100)

-- You can add as many variables as
-- you wish and access them by using
-- beautiful.variable in your rc.lua
--theme.bg_widget = "#cc0000"

-- Define the image to load
theme.titlebar_close_button_normal = files.."/titlebar/close_normal.png"
theme.titlebar_close_button_focus  = files.."/titlebar/close_focus.png"

theme.titlebar_minimize_button_normal = files.."/titlebar/minimize_normal.png"
theme.titlebar_minimize_button_focus  = files.."/titlebar/minimize_focus.png"

theme.titlebar_ontop_button_normal_inactive = files.."/titlebar/ontop_normal_inactive.png"
theme.titlebar_ontop_button_focus_inactive  = files.."/titlebar/ontop_focus_inactive.png"
theme.titlebar_ontop_button_normal_active = files.."/titlebar/ontop_normal_active.png"
theme.titlebar_ontop_button_focus_active  = files.."/titlebar/ontop_focus_active.png"

theme.titlebar_sticky_button_normal_inactive = files.."/titlebar/sticky_normal_inactive.png"
theme.titlebar_sticky_button_focus_inactive  = files.."/titlebar/sticky_focus_inactive.png"
theme.titlebar_sticky_button_normal_active = files.."/titlebar/sticky_normal_active.png"
theme.titlebar_sticky_button_focus_active  = files.."/titlebar/sticky_focus_active.png"

theme.titlebar_floating_button_normal_inactive = files.."/titlebar/floating_normal_inactive.png"
theme.titlebar_floating_button_focus_inactive  = files.."/titlebar/floating_focus_inactive.png"
theme.titlebar_floating_button_normal_active = files.."/titlebar/floating_normal_active.png"
theme.titlebar_floating_button_focus_active  = files.."/titlebar/floating_focus_active.png"

theme.titlebar_maximized_button_normal_inactive = files.."/titlebar/maximized_normal_inactive.png"
theme.titlebar_maximized_button_focus_inactive  = files.."/titlebar/maximized_focus_inactive.png"
theme.titlebar_maximized_button_normal_active = files.."/titlebar/maximized_normal_active.png"
theme.titlebar_maximized_button_focus_active  = files.."/titlebar/maximized_focus_active.png"

-- You can use your own layout icons like this:
theme.layout_fairh = files.."/layouts/fairhw.png"
theme.layout_fairv = files.."/layouts/fairvw.png"
theme.layout_floating  = files.."/layouts/floatingw.png"
theme.layout_magnifier = files.."/layouts/magnifierw.png"
theme.layout_max = files.."/layouts/maxw.png"
theme.layout_fullscreen = files.."/layouts/fullscreenw.png"
theme.layout_tilebottom = files.."/layouts/tilebottomw.png"
theme.layout_tileleft   = files.."/layouts/tileleftw.png"
theme.layout_tile = files.."/layouts/tilew.png"
theme.layout_tiletop = files.."/layouts/tiletopw.png"
theme.layout_spiral  = files.."/layouts/spiralw.png"
theme.layout_dwindle = files.."/layouts/dwindlew.png"
theme.layout_cornernw = files.."/layouts/cornernww.png"
theme.layout_cornerne = files.."/layouts/cornernew.png"
theme.layout_cornersw = files.."/layouts/cornersww.png"
theme.layout_cornerse = files.."/layouts/cornersew.png"

-- Generate Awesome icon:
theme.awesome_icon = theme_assets.awesome_icon(
    theme.menu_height, theme.bg_focus, theme.fg_focus
)

-- Define the icon theme for application icons. If not set then the icons
-- from /usr/share/icons and /usr/share/icons/hicolor will be used.
theme.icon_theme = nil

return theme

-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
